---
title: VRChat
weight: 50
---

# VRChat

The most popular social VR game, here are resources to get the best experience on Linux.

## Recommendations

Proton version: [Proton-GE-RTSP](https://github.com/SpookySkeletons/proton-ge-rtsp/releases) - this will give you the most painless experience.

### Performance Tuning

In VRC, it's very easy to hit a CPU bottleneck. Avatar material count, avatar mesh count, pixel light count, phys bones, particles all contribute to CPU load.

How to check if you're bottlenecked by CPU or GPU:
- Check GPU usage in `nvtop` (any GPU) or `nvidia-smi` (NVidia-only).
  - If it's not at 100%, you're likely CPU bottlenecked.
- SteamVR: Lower the SteamVR render resolution.
  - If your FPS doesn't increase, you're likely CPU bottlenecked.

What to do if CPU bottlenecked:
 - Reduce Maximum Shown Avatars
   - I recommend 10-15 as a base setting, likely won't be interacting with more people than that at the same time.
 - Block Poorly Optimized Avatars: Very Poor
   - Can still show-avatar people who you are actively interacting with.
   - Will often notice that showing a speficic person's avatar will wreck your performance, while everyone else's avatars are fine. Blocking very poor by default makes you more aware on whose avatar has a large impact.
 - Optimize your avatar, and nag your friends to do the same.
   - There are many tools that let you do this in a few clicks, even if you are completely clueless about what to do.
   - d4rkAvatarOptimizer 
     - `vrc-get repo add https://d4rkc0d3r.github.io/vpm-repos/main.json`
     - [Guide](https://github.com/d4rkc0d3r/d4rkAvatarOptimizer)
   - Avatar Optimizer by Anatawa12
     - `vrc-get repo add https://vpm.anatawa12.com/vpm.json`
     - [Guide](https://vpm.anatawa12.com/avatar-optimizer/en/docs/tutorial/basic-usage/)


In-game settings:
- Graphics:
  - Anti-Aliasing: Off or 2x
    - Greatly increases GPU load (even more so on NVidia)
    - Try with off first, if the jagged edges bother you too much, try 2x.
  - Pixel light count: Low 
    - Each pixel light adds significant CPU load.
    - Turning these completely off will make some worlds look incorrect (too dark).
  - Shadow Quality: Low
    - Adds significant GPU load.

## Common issues

If you utilize pipewire [this workaround is required not to drop audio from time to time](https://wiki.archlinux.org/title/PipeWire#Audio_cutting_out_when_multiple_streams_start_playing) on displayport audio headsets like the valve index. (Controversial; same issue also encountered on other servers.)

When hosting a lobby west servers should always be utilized instead of east servers as the infrastructure is significantly more reliable.

Should the game prompt to exit the game upon an anticheat failure, simply try to load the game again until it works. [See EAC section](eac.md)

Given a [few caveats](video_players.md) most video players will work.

VRChat maintains a host of quite extensive privacy concerns, please consider your opsec in relation to body pose info, voice communication, and unsandboxed execution risk if necessary, all of these are active concerns.